<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrl="http://netkernel.org/xrl" xmlns:nk="http://netkernel.org">
  <xsl:output method="xml"/>

	<xsl:param name="repocollectionid" nk:class="java.lang.String"/>
	<xsl:param name="repocollectionsetid" nk:class="java.lang.String"/>

  <xsl:template match="/packages">
  <batch>
  	<sql>BEGIN</sql>
  	<xsl:apply-templates select="package"/>
  	<sql>COMMIT</sql>
  </batch>
  </xsl:template>

	<xsl:template match="package">
		<sql>
			MERGE INTO PACKAGES(
                REPOCOLLECTIONSETID,
				NAME,
				DESCR,
				MAINTAINER,
				RUNLEVEL,
				SECTION,
				WWW,
				LICENSE
			)
			KEY (REPOCOLLECTIONSETID, NAME)
			VALUES
			(
			<xsl:value-of select="$repocollectionsetid"/>,
			'<xsl:value-of select="name"/>',
			'<xsl:value-of select="packagedescr"/>',
			'<xsl:value-of select="maintainer"/>',
			<xsl:value-of select="runlevel"/>,
			'<xsl:value-of select="section"/>',
			'<xsl:value-of select="www"/>',
			'<xsl:value-of select="license"/>'
			)
			;
		</sql>
		<sql>
			MERGE INTO PACKAGE_VERSIONS(
				PACKAGEID,
				VERSION,
				SIZE,
				INSTALLED,
				TYPE,
				FILENAME,
				FILEPATH,
				LOCALSRC,
				DESCR,
				SIGNATURE,
				MD5,
				SHA256
			)
			KEY (PACKAGEID, VERSION)
			VALUES
			(
				(	SELECT ID FROM PACKAGES
						WHERE
							NAME='<xsl:value-of select="name"/>'
							AND
							REPOCOLLECTIONSETID=<xsl:value-of select="$repocollectionsetid"/>
				), 	
				 ( <xsl:value-of select="translate(version, '.', ',')"/> ),
				 <xsl:value-of select="size"/>,
				(	 	SELECT INSTALLED FROM
					 	PACKAGES, PACKAGE_VERSIONS
					 	WHERE
					 	PACKAGES.NAME='<xsl:value-of select="name"/>'
					 	AND
					 	PACKAGES.REPOCOLLECTIONSETID=<xsl:value-of select="$repocollectionsetid"/>
					 	AND
					 	PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
						AND
						PACKAGE_VERSIONS.VERSION=( <xsl:value-of select="translate(version, '.', ',')"/> )
				  ),
				 1,
				 '<xsl:value-of select="filename"/>',
				 '<xsl:value-of select="filepath"/>',
				 NULL,
				 '<xsl:value-of select="versiondescr"/>',
				 '<xsl:value-of select="trust/signature"/>',
				 '<xsl:value-of select="trust/md5"/>',
				 '<xsl:value-of select="trust/sha256"/>'
				)
				;
		</sql>
		<sql>
			UPDATE PACKAGE_VERSIONS SET INSTALLED=FALSE WHERE INSTALLED IS NULL;
		</sql>
	</xsl:template>
	<!--
	
	(	SELECT ID FROM PACKAGES
						WHERE
							NAME='<xsl:value-of select="name"/>'
							AND
							REPOCOLLECTIONID=1
				),
	
	CREATE TABLE PACKAGES
	(	ID												IDENTITY PRIMARY KEY,
		REPOCOLLECTIONID			INTEGER,
		NAME											VARCHAR(1024),
		DESCR										TEXT,
		MAINTAINER								VARCHAR(1024),
		RUNLEVEL								INTEGER,
		SECTION									VARCHAR(512),
		WWW											VARCHAR(2048),
		LICENSE									VARCHAR(1024)
	);
	
	CREATE TABLE IF NOT EXISTS PACKAGE_VERSIONS
	(	ID												IDENTITY PRIMARY KEY,
		PACKAGEID								INTEGER,
		VERSION									ARRAY,
		SIZE											INTEGER,
		INSTALLED								BOOLEAN,
		TYPE											INTEGER,   1 main, 2 update, 3 security
		REPOSRC								VARCHAR(2048),
		LOCALSRC								VARCHAR(2048),
		DESCR										TEXT,
		SIGNATURE								VARCHAR(2048),
		MD5											VARCHAR(128),
		SHA256										VARCHAR(512)
	);
	-->
	

</xsl:stylesheet> 
